#include "DX11Device.h"

CDirectX::CDirectX(HWND hWnd)
{
	m_pD3dDevice = NULL;
	m_pSwapChain = NULL;
	m_pDeviceContext = NULL;
	m_pRenderTargetView =NULL;

	Init3D(hWnd);
}

CDirectX::~CDirectX()
{
	Clean3D();
}

HRESULT CDirectX::Init3D(HWND hWnd)
{
	DXGI_SWAP_CHAIN_DESC sd;
	ZeroMemory(&sd, sizeof(sd));

	sd.BufferCount = 1;
	sd.BufferDesc.Format = DXGI_FORMAT_R8G8B8A8_UNORM;
	sd.BufferUsage = DXGI_USAGE_RENDER_TARGET_OUTPUT;
	sd.OutputWindow = hWnd;
	sd.SampleDesc.Count = 1;
	sd.Windowed = true;

	D3D11CreateDeviceAndSwapChain(NULL, D3D_DRIVER_TYPE_HARDWARE,
		NULL, NULL, NULL, NULL, D3D11_SDK_VERSION, &sd, &m_pSwapChain,
		&m_pD3dDevice, NULL, &m_pDeviceContext);

	//Backbuffer set
	ID3D11Texture2D *pBackBuffer;
	m_pSwapChain->GetBuffer(0, __uuidof(ID3D11Texture2D), (LPVOID*)&pBackBuffer);
	m_pD3dDevice->CreateRenderTargetView(pBackBuffer, NULL, &m_pRenderTargetView);
	pBackBuffer->Release();
	m_pDeviceContext->OMSetRenderTargets(1, &m_pRenderTargetView, NULL);

	//Viewport set
	D3D11_VIEWPORT viewport;
	ZeroMemory(&viewport, sizeof(D3D11_VIEWPORT));
	viewport.TopLeftX = 0;
	viewport.TopLeftY = 0;
	viewport.Width = 1280;
	viewport.Height = 720;
	m_pDeviceContext->RSSetViewports(1, &viewport);

	return S_OK;
}

VOID CDirectX::Clean3D()
{
	m_pSwapChain->Release();
	m_pD3dDevice->Release();
	m_pDeviceContext->Release();
	m_pRenderTargetView->Release();
}

VOID CDirectX::Render()
{
	float ClearColor[4] = {0.0f, 0.0f, 1.0f, 1.0f};
	m_pDeviceContext->ClearRenderTargetView(m_pRenderTargetView, ClearColor);
	m_pSwapChain->Present(0,0);
}